#!/usr/bin/env python3
#
# Copyright 2024 ROBOTIS CO., LTD.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Author: Wonho Yoon, Sungho Woo

import os

from ament_index_python.packages import get_package_share_directory
from launch import LaunchDescription
from launch.actions import DeclareLaunchArgument
from launch.substitutions import LaunchConfiguration
from launch_ros.actions import Node
import xacro


def generate_launch_description():

    ld = LaunchDescription()
    publish_frequency = LaunchConfiguration('publish_frequency')
    ld.add_action(DeclareLaunchArgument('publish_frequency', default_value='15.0'))

    # Robot description
    robot_description_config = xacro.process_file(
        os.path.join(
            get_package_share_directory('open_manipulator_x_description'),
            'urdf',
            'open_manipulator_x_robot.urdf.xacro',
        )
    )
    robot_description = {'robot_description': robot_description_config.toxml()}

    # Given the published joint states, publish tf for the robot links and the robot description
    rsp_node = Node(
        package='robot_state_publisher',
        executable='robot_state_publisher',
        respawn=True,
        output='screen',
        parameters=[{'publish_frequency': publish_frequency}, robot_description]
    )

    ld.add_action(rsp_node)

    return ld
